@@ -276,11 +276,11 @@ i_ft2_set_mm_coords(FT2_Fonthandle *handle, int coord_count, const long *coords)
 
 #ifdef WIN32
 
-extern int i_wf_bbox(const char *face, int size, const char *text, int length, int *bbox);
+extern int i_wf_bbox(const char *face, int size, const char *text, int length, int *bbox, int utf8);
 extern int i_wf_text(const char *face, i_img *im, int tx, int ty, const i_color *cl, 
-		     int size, const char *text, int len, int align, int aa);
+		     int size, const char *text, int len, int align, int aa, int utf8);
 extern int i_wf_cp(const char *face, i_img *im, int tx, int ty, int channel, 
-		   int size, const char *text, int len, int align, int aa);
+		   int size, const char *text, int len, int align, int aa, int utf8);
 extern int i_wf_addfont(char const *file);
 
 #endif
